package com.fuyuanshen.app.service;

import com.fuyuanshen.app.domain.vo.AppOperationVideoVo;
import com.fuyuanshen.app.domain.bo.AppOperationVideoBo;
import com.fuyuanshen.common.mybatis.core.page.TableDataInfo;
import com.fuyuanshen.common.mybatis.core.page.PageQuery;

import java.util.Collection;
import java.util.List;

/**
 * 操作视频Service接口
 *
 * @author Lion Li
 * @date 2025-07-02
 */
public interface IAppOperationVideoService {

    /**
     * 查询操作视频
     *
     * @param id 主键
     * @return 操作视频
     */
    AppOperationVideoVo queryById(Long id);

    /**
     * 分页查询操作视频列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 操作视频分页列表
     */
    TableDataInfo<AppOperationVideoVo> queryPageList(AppOperationVideoBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的操作视频列表
     *
     * @param bo 查询条件
     * @return 操作视频列表
     */
    List<AppOperationVideoVo> queryList(AppOperationVideoBo bo);

    /**
     * 新增操作视频
     *
     * @param bo 操作视频
     * @return 是否新增成功
     */
    Boolean insertByBo(AppOperationVideoBo bo);

    /**
     * 修改操作视频
     *
     * @param bo 操作视频
     * @return 是否修改成功
     */
    Boolean updateByBo(AppOperationVideoBo bo);

    /**
     * 校验并批量删除操作视频信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
