package com.fuyuanshen.app.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.fuyuanshen.app.mapper.AppRoleMapper;
import com.fuyuanshen.common.core.utils.MapstructUtils;
import com.fuyuanshen.common.core.utils.StringUtils;
import com.fuyuanshen.common.mybatis.core.page.TableDataInfo;
import com.fuyuanshen.common.mybatis.core.page.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import com.fuyuanshen.app.domain.bo.AppMenuBo;
import com.fuyuanshen.app.domain.vo.AppMenuVo;
import com.fuyuanshen.app.domain.AppMenu;
import com.fuyuanshen.app.mapper.AppMenuMapper;
import com.fuyuanshen.app.service.IAppMenuService;

import java.util.*;

/**
 * 菜单权限Service业务层处理
 *
 * @author Lion Li
 * @date 2025-06-27
 */
@Slf4j
@RequiredArgsConstructor
@Service
public class AppMenuServiceImpl implements IAppMenuService {

    private final AppMenuMapper baseMapper;
    /**
     * 根据用户ID查询权限
     *
     * @param userId 用户ID
     * @return 权限列表
     */
    @Override
    public Set<String> selectMenuPermsByUserId(Long userId) {
        List<String> perms = baseMapper.selectMenuPermsByUserId(userId);
        Set<String> permsSet = new HashSet<>();
        for (String perm : perms) {
            if (StringUtils.isNotEmpty(perm)) {
                permsSet.addAll(StringUtils.splitList(perm.trim()));
            }
        }
        return permsSet;
    }
}
